import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class CoolStepperCustomConfig {
  /// The Widget that that should be displayed in place of the back button
  ///
  /// default is 'BACK'
  final String? backText;

  /// The style for the back text
  final TextStyle? backTextStyle;

  /// The style for the back button
  final ButtonStyle? backButtonStyle;

  /// The padding for the back button
  final EdgeInsetsGeometry? backButtonPadding;

  /// The text that should be displayed for the next button
  ///
  /// default is a Button with text 'NEXT'
  final String? nextText;

  /// The style for the next text
  final TextStyle? nextTextStyle;

  /// The style for the next button
  final ButtonStyle? nextButtonStyle;

  /// The padding for the next button
  final EdgeInsetsGeometry? nextButtonPadding;

  /// The text that describes the progress
  ///
  /// default is a Button with text 'STEP'
  final String? stepText;

  /// The text that describes the progress
  ///
  /// default is 'OF'
  final String? ofText;

  /// This is the background color of the header
  final Color? headerColor;

  /// This is the color of the icon
  ///
  /// [This does not apply when icon is set]
  final Color? iconColor;

  /// This icon replaces the default icon
  final Icon? icon;

  /// This is the textStyle for the title text
  final TextStyle? titleTextStyle;

  /// This is the textStyle for the subtitle text
  final TextStyle? subtitleTextStyle;

  /// A List of string that when supplied will override 'backText'
  ///
  /// Must be one less than the number of steps since for the first step, the backText won't be visible
  final List<String>? backTextList;

  /// A List of string that when supplied will override 'nextText'
  ///
  /// Must be one less than the number of steps since the 'finalText' attribute is able to set the value for the final step's next button
  final List<String>? nextTextList;

  /// The text that should be displayed for the next button on the final step
  ///
  /// default is 'FINISH'
  final String? finalText;

  /// The style for the final text
  final TextStyle? finalTextStyle;

  /// The style for the final button
  final ButtonStyle? finalButtonStyle;

  /// The padding for the final button
  final EdgeInsetsGeometry? finalButtonPadding;

  final bool isHeaderEnabled;

  const CoolStepperCustomConfig({
    this.backText = 'PRE',
    this.nextText = 'NEXT',
    this.stepText = 'STEP',
    this.ofText = 'OF',
    this.headerColor,
    this.iconColor,
    this.icon,
    this.titleTextStyle,
    this.subtitleTextStyle,
    this.backTextList,
    this.nextTextList,
    this.finalText = 'FINISH',
    this.isHeaderEnabled = true,
    this.backTextStyle,
    this.backButtonStyle,
    this.backButtonPadding,
    this.nextTextStyle,
    this.nextButtonStyle,
    this.nextButtonPadding,
    this.finalTextStyle,
    this.finalButtonStyle,
    this.finalButtonPadding,
  });
}
